import { useCallback, useEffect, useMemo, useState } from 'react';
export const useWsApi = (wsApiUrl) => {
    const [error, setError] = useState(false);
    const [connected, setConnected] = useState(false);
    const [request, setRequest] = useState();
    const [route, setRoute] = useState();
    const [options, setOptions] = useState();
    const handleConnected = useCallback(() => {
        setConnected(true);
        setError(false);
        options?.onConnected?.();
    }, [options]);
    const handleError = useCallback((error) => {
        setError(false);
        options?.onError?.(error);
    }, [options]);
    const handleResponse = useCallback((response) => {
        setError(false);
        options?.onResponse?.(response);
    }, [options]);
    const handleDisconnected = useCallback(() => {
        setConnected(false);
        options?.onDisconnected?.();
    }, [options]);
    const websocket = useMemo(() => {
        if (!route)
            return null;
        if (!request)
            return null;
        const websocket = new WebSocket(wsApiUrl);
        websocket.onopen = () => {
            websocket.send(JSON.stringify({
                action: route.action,
                ...request,
            }));
            handleConnected();
        };
        websocket.onmessage = (ev) => {
            if (!ev.data || ev.data === '{}')
                return;
            handleResponse(JSON.parse(ev.data));
        };
        websocket.onerror = (error) => handleError(error);
        websocket.onclose = () => handleDisconnected();
        return websocket;
    }, [route, request]);
    // send request
    useEffect(() => {
        if (!route)
            return;
    }, [request, route?.action, websocket, request]);
    const sendRequest = useCallback((route, request, options) => {
        setConnected(true);
        setRoute(route);
        setRequest(request);
        setOptions(options);
    }, []);
    const disconnect = useCallback(() => {
        websocket?.close();
        handleDisconnected?.();
    }, [websocket, handleDisconnected]);
    return {
        sendRequest,
        connected,
        error,
        disconnect,
    };
};
//# sourceMappingURL=useWsApi.js.map